@@ -86,7 +86,7 @@ def mk_handle(args, kdamonds, monitoring_intervals):
             # for children processes recording and memory footprint
             kdamonds=kdamonds, add_child_tasks=args.include_child_tasks,
             record_mem_footprint=args.footprint,
-            record_vmas=args.vmas, timeout=None)
+            record_vmas=args.vmas, timeout=args.timeout)
 
     if args.snapshot is not None:
         handle.tracepoint = None
@@ -152,7 +152,7 @@ def main(args):
     cleanup_exit(0)
 
 def set_argparser(parser):
-    parser = _damon_args.set_argparser(parser, add_record_options=True)
+    _damon_args.set_argparser(parser, add_record_options=True, min_help=True)
     parser.add_argument('--output_type',
                         choices=_damo_records.file_types,
                         default=_damo_records.file_type_json_compressed,
@@ -177,5 +177,7 @@ def set_argparser(parser):
                         help='record virtual memory areas (/proc/<pid>/maps)')
     parser.add_argument('--snapshot', metavar=('<delay>', '<count>'), nargs=2,
                         type=float, help='record accesses as snapshots')
+    parser.add_argument('--timeout', type=float, metavar='<seconds>',
+                        help='stop recording after the given seconds')
     parser.description = 'Record monitoring results'
     return parser
